@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Excon
   module Middleware
     class CaptureCookies < Excon::Middleware::Base
@@ -7,7 +8,7 @@ module Excon
       end
 
       def get_header(datum, header)
-        _, header_value = datum[:response][:headers].detect do |key, value|
+        _, header_value = datum[:response][:headers].detect do |key, _|
           key.casecmp(header) == 0
         end
         header_value
