@@ -1,10 +1,19 @@
+# frozen_string_literal: true
 module Excon
   module Middleware
     class Mock < Excon::Middleware::Base
+      def self.valid_parameter_keys
+        [
+          :allow_unstubbed_requests,
+          :captures,
+          :mock
+        ]
+      end
+
       def request_call(datum)
         if datum[:mock]
           # convert File/Tempfile body to string before matching:
-          unless datum[:body].nil? || datum[:body].is_a?(String)
+          if datum[:body].respond_to?(:read)
            if datum[:body].respond_to?(:binmode)
              datum[:body].binmode
            end
@@ -12,14 +21,17 @@ module Excon
              datum[:body].rewind
            end
            datum[:body] = datum[:body].read
+          elsif !datum[:body].nil? && !datum[:body].is_a?(String)
+            raise Excon::Errors::InvalidStub.new("Request body should be a string or an IO object. #{datum[:body].class} provided")
           end
 
-          if stub = Excon.stub_for(datum)
+          if (stub = Excon.stub_for(datum))
+            datum[:remote_ip] ||= '127.0.0.1'
             datum[:response] = {
               :body       => '',
               :headers    => {},
               :status     => 200,
-              :remote_ip  => '127.0.0.1'
+              :remote_ip  => datum[:remote_ip]
             }
 
             stub_datum = case stub.last
@@ -29,13 +41,16 @@ module Excon
               stub.last
             end
 
-            datum[:response].merge!(stub_datum.reject {|key,value| key == :headers})
+            datum[:response].merge!(stub_datum.reject {|key,_| key == :headers})
             if stub_datum.has_key?(:headers)
               datum[:response][:headers].merge!(stub_datum[:headers])
             end
-          else
+          elsif datum[:allow_unstubbed_requests] != true
             # if we reach here no stubs matched
-            raise(Excon::Errors::StubNotFound.new('no stubs matched ' << datum.inspect))
+            message = StringIO.new
+            message.puts('no stubs matched')
+            Excon::PrettyPrinter.pp(message, datum)
+            raise(Excon::Errors::StubNotFound.new(message.string))
           end
         end
 
