@@ -1,25 +1,17 @@
 require "spec_helper"
 
 describe Excon::Connection do
+  include_context('stubs')
   context "when speaking to a UNIX socket" do
     context "Host header handling" do
       before do
-        responder = ->(req) do
+        Excon.stub do |req|
           {
             body: req[:headers].to_json,
             status: 200,
           }
         end
-
-        @original_mock = Excon.defaults[:mock]
-        Excon.defaults[:mock] = true
-        Excon.stub({}, responder)
       end
-
-      after do
-        Excon.defaults[:mock] = @original_mock
-      end
-
       it "sends an empty Host= by default" do
         conn = Excon::Connection.new(
           scheme: "unix",
