@@ -91,8 +91,10 @@ shared_examples_for 'a basic client' do |url = 'http://127.0.0.1:9292', opts = {
             data = []
             it 'yields with a chunk, remaining length, and total length' do
               expect do
-                conn.request(method: :get, path: '/content-length/100') do |chunk, remaining_length, total_length|
-                  data = [chunk, remaining_length, total_length]
+                silence_warnings do
+                  conn.request(method: :get, path: '/content-length/100') do |chunk, remaining_length, total_length|
+                    data = [chunk, remaining_length, total_length]
+                  end
                 end
               end.to_not raise_error
             end
@@ -163,6 +165,15 @@ shared_examples_for 'a basic client' do |url = 'http://127.0.0.1:9292', opts = {
             end
 
             context 'when a string is the body paramter' do
+              it 'does not change the enconding of the body' do
+                skip unless RUBY_VERSION >= '2.0'
+
+                string_body = '¥£€'
+                expect do
+                  conn.request(method: :post, path: '/echo', body: string_body)
+                end.to_not change { string_body.encoding }
+              end
+
               context 'without request_block' do
                 describe Excon::Response do
                   it "#body equals 'x' * 100)" do
