@@ -1,5 +1,3 @@
-#!/usr/bin/env ruby
-
 require 'eventmachine'
 require 'stringio'
 require 'uri'
@@ -342,9 +340,3 @@ module GoodServer
                         (?:,\s*|\Z)'xn).flatten
   end
 end
-
-EM.run do
-  EM.start_server("127.0.0.1", 9292, GoodServer)
-  EM.start_server("::1", 9293, GoodServer) unless RUBY_PLATFORM == 'java'
-  $stderr.puts "ready"
-end
